==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPaneDragEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDetailDescription } from "./WebPaneDragEndEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneDragEndEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragEndEventArgsDetailDescriptionMetadata, _super);
    function WebPaneDragEndEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragEndEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneDragEndEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneDragEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragEndEventArgsDetailDescriptionMetadata.c(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragEndEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPaneDragEndEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragEndEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Array:WebContentPaneDescription:ContentPane");
    };
    WebPaneDragEndEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneDragEndEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebPaneDragEndEventArgsDetail", function () { return new WebPaneDragEndEventArgsDetailDescription(); });
        a.ac("WebPaneDragEndEventArgsDetail", WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneDragEndEventArgsDetailDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDetailDescriptionMetadata, 'WebPaneDragEndEventArgsDetailDescriptionMetadata');
    WebPaneDragEndEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneDragEndEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebPaneDragEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDetailDescription } from "./WebPaneDragEndEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneDragEndEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragEndEventArgsDetailDescriptionMetadata, _super);
    function WebPaneDragEndEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragEndEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneDragEndEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneDragEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragEndEventArgsDetailDescriptionMetadata.c(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragEndEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebPaneDragEndEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragEndEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
    };
    WebPaneDragEndEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneDragEndEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebPaneDragEndEventArgsDetail", function () { return new WebPaneDragEndEventArgsDetailDescription(); });
        a.ad("WebPaneDragEndEventArgsDetail", WebPaneDragEndEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneDragEndEventArgsDetailDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDetailDescriptionMetadata, 'WebPaneDragEndEventArgsDetailDescriptionMetadata');
    WebPaneDragEndEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneDragEndEventArgsDetailDescriptionMetadata };
